## Copyright (C) 2004 Eric Chassande-Mottin
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

function [tfr,t,f] = dwv_odd(x,t,fs);
% computes the part of DWV involving odd terms (sum of indices is an odd number)

if (nargin == 0),
 error('At least one parameter required');
end;

[xrow,xcol] = size(x);
N=xrow; N2=2*N;

if (nargin == 1),
  t=1:xrow; fs=1; trace=0;
elseif (nargin == 2),
  fs=1; trace=0;
elseif (nargin ==3),
  trace=0;
end;

[trow,tcol] = size(t);
if (xcol==0)|(xcol>2),
  error('X must have one or two columns');
elseif (trow~=1),
  error('T must only have one row'); 
elseif (2^nextpow2(N)~=N),
  error('N must be a power of two');
end; 

tfr=lxcf(x,[0;x(1:N-1)],t);
tfr= fft(tfr)/fs; 
m=exp(-i*pi*(0:N2-1)'/N);
tfr=real([tfr;tfr].*(m*ones(1,N)));

if (nargout==3),
 f=fs*(0:N2-1)'/N2;
end;
