## Copyright (C) 2004 Eric Chassande-Mottin
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

% linear chirp, comparison of various WV distributions
% check the shape of dwv_even and dwv_odd 

clear;

% -- init
debug=0;              % make plot with octave yes=0, no=1

% -- signal

N1=127;
t1=(0:N1-1);
p1=pi/2*t1.^2/(N1-1);
x1=exp(i*p1');
x1=x1/norm(x1);

N2=128;
t2=(0:N2-1);
p2=pi/2*t2.^2/(N2-1);
x2=exp(i*p2');
x2=x2/norm(x2);

% -- compute tfr
tfr0=dwv0(x2); % Claasen/Mecklenbrauker

tfr=dwv(x2);   % Chassande/Pai

tfre=dwv_even(x2); % even term

tfro=dwv_odd(x2); % odd term

tfr1=dwv1(x2); % Peyrin/Prost

tfr2=dwv2(x1); % Richman et al./O'Neill et al.

% -- make plots

if (debug==0)
  multiplot(2,3);
  gset nokey;
  
  subplot(2,3,1);
  contour(tfr0',[.25 -.25]);
  eval(sprintf('gset xrange [0:%d];',N2));
  eval(sprintf('gset yrange [0:%d];',2*N2));
  xlabel('time');
  ylabel('frequency');
  title('(a)');
  
  subplot(2,3,2);
  contour(tfr',[.25 -.25]);
  eval(sprintf('gset xrange [0:%d];',N2));
  eval(sprintf('gset yrange [0:%d];',2*N2));
  xlabel('time');
  ylabel('frequency');
  title('(b)');
  
  subplot(2,3,3);
  contour(tfr1',[.25 -.25]);
  eval(sprintf('gset xrange [0:%d];',2*N2));
  eval(sprintf('gset yrange [0:%d];',2*N2));
  xlabel('time');
  ylabel('frequency');
  title('(c)');

  subplot(2,3,4);
  contour(tfr2',[.25 -.25]);
  eval(sprintf('gset xrange [0:%d];',N1));
  eval(sprintf('gset yrange [0:%d];',N1));
  xlabel('time');
  ylabel('frequency');
  title('(d)');

  subplot(2,3,5);
  contour(tfre',[.25 -.25]);
  eval(sprintf('gset xrange [0:%d];',N2));
  eval(sprintf('gset yrange [0:%d];',2*N2));
  xlabel('time');
  ylabel('frequency');
  title('(e)');
  
  subplot(2,3,6);
  contour(tfro',[.25 -.25]);
  eval(sprintf('gset xrange [0:%d];',N2));
  eval(sprintf('gset yrange [0:%d];',2*N2));
  xlabel('time');
  ylabel('frequency');
  title('(f)');

% -- relax
  oneplot();
  gset autoscale x
  gset autoscale y
  gset term x11
  
end;

save -mat-binary figure.mat tfr*

printf("wrote figure.mat\n now, run the script figure_plot.m to make the figure\n");


